@@ -1,3 +1,4 @@
+pub use reqwest;
 use {
     crate::{rpc_request, rpc_response},
     solana_faucet::faucet::FaucetError,
@@ -6,9 +7,7 @@ use {
     },
     std::io,
     thiserror::Error,
-};
-
-pub use reqwest; // export `reqwest` for clients
+}; // export `reqwest` for clients
 
 #[derive(Error, Debug)]
 pub enum ClientErrorKind {
